@@ -8,11 +8,11 @@ from pydocstringformatter.utils.exceptions import (
     PydocstringFormatterError,
 )
 
-__version__ = "0.2.0"
+__version__ = "0.5.0"
 
 
 def run_docstring_formatter(argv: Union[List[str], None] = None) -> None:
-    """Run the formatter"""
+    """Run the formatter."""
     from pydocstringformatter.run import _Run
 
     _Run(argv or sys.argv[1:])
