@@ -1,23 +1,19 @@
-from pydocstringformatter.utils.argument_parsing import (
-    _parse_command_line_arguments,
-    _parse_toml_file,
-    _register_arguments,
-)
 from pydocstringformatter.utils.exceptions import (
     ParsingError,
     PydocstringFormatterError,
     TomlParsingError,
 )
+from pydocstringformatter.utils.file_diference import _generate_diff
 from pydocstringformatter.utils.find_docstrings import _is_docstring
 from pydocstringformatter.utils.find_python_file import _find_python_files
+from pydocstringformatter.utils.output import _print_to_console
 
 __all__ = [
     "_find_python_files",
+    "_generate_diff",
     "_is_docstring",
-    "_parse_command_line_arguments",
-    "_register_arguments",
-    "PydocstringFormatterError",
     "ParsingError",
-    "_parse_toml_file",
+    "PydocstringFormatterError",
     "TomlParsingError",
+    "_print_to_console",
 ]
